#ifndef NT2_INCLUDE_FUNCTIONS_ITRUNC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ITRUNC_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/itrunc.hpp>

#endif
